@@ -6,7 +6,7 @@
 --	Copyright (c) 2003-2009, PostgreSQL Global Development Group
 --	Author: Jan Wieck, Afilias USA INC.
 --
--- $Id: slony1_base.sql,v 1.32.2.3 2009-08-17 17:39:57 devrim Exp $
+-- 
 -- ----------------------------------------------------------------------
 
 
@@ -22,8 +22,6 @@ create table @NAMESPACE@.sl_node (
 	no_id				int4,
 	no_active			bool,
 	no_comment			text,
-	no_spool			boolean,
-
 	CONSTRAINT "sl_node-pkey"
 		PRIMARY KEY (no_id)
 ) WITHOUT OIDS;
@@ -31,7 +29,6 @@ comment on table @NAMESPACE@.sl_node is 'Holds the list of nodes associated with
 comment on column @NAMESPACE@.sl_node.no_id is 'The unique ID number for the node';  
 comment on column @NAMESPACE@.sl_node.no_active is 'Is the node active in replication yet?';  
 comment on column @NAMESPACE@.sl_node.no_comment is 'A human-oriented description of the node';
-comment on column @NAMESPACE@.sl_node.no_spool is 'Is the node being used for log shipping?';  
 
 
 -- ----------------------------------------------------------------------
@@ -57,7 +54,7 @@ comment on column @NAMESPACE@.sl_nodelock.nl_backendpid is 'PID of database back
 create table @NAMESPACE@.sl_set (
 	set_id				int4,
 	set_origin			int4,
-	set_locked			@NAMESPACE@.xxid,
+	set_locked			bigint,
 	set_comment			text,
 
 	CONSTRAINT "sl_set-pkey"
@@ -70,7 +67,7 @@ comment on table @NAMESPACE@.sl_set is 'Holds definitions of replication sets.';
 comment on column @NAMESPACE@.sl_set.set_id is 'A unique ID number for the set.';
 comment on column @NAMESPACE@.sl_set.set_origin is 
 	'The ID number of the source node for the replication set.';
-comment on column @NAMESPACE@.sl_set.set_locked is 'Indicates whether or not the set is locked.';
+comment on column @NAMESPACE@.sl_set.set_locked is 'Transaction ID where the set was locked.';
 comment on column @NAMESPACE@.sl_set.set_comment is 'A human-oriented description of the set.';
 
 
@@ -81,9 +78,7 @@ create table @NAMESPACE@.sl_setsync (
 	ssy_setid			int4,
 	ssy_origin			int4,
 	ssy_seqno			int8,
-	ssy_minxid			@NAMESPACE@.xxid,
-	ssy_maxxid			@NAMESPACE@.xxid,
-	ssy_xip				text,
+	ssy_snapshot		"pg_catalog".txid_snapshot,
 	ssy_action_list		text,
 
 	CONSTRAINT "sl_setsync-pkey"
@@ -99,10 +94,8 @@ comment on table  @NAMESPACE@.sl_setsync is 'SYNC information';
 comment on column @NAMESPACE@.sl_setsync.ssy_setid is 'ID number of the replication set';
 comment on column @NAMESPACE@.sl_setsync.ssy_origin is 'ID number of the node';
 comment on column @NAMESPACE@.sl_setsync.ssy_seqno is 'Slony-I sequence number';
-comment on column @NAMESPACE@.sl_setsync.ssy_minxid is 'Earliest XID in provider system affected by SYNC';
-comment on column @NAMESPACE@.sl_setsync.ssy_maxxid is 'Latest XID in provider system affected by SYNC';
-comment on column @NAMESPACE@.sl_setsync.ssy_xip is 'Contains the list of XIDs in progress at SYNC time';
-comment on column @NAMESPACE@.sl_setsync.ssy_action_list is 'action list used during the subscription process. At the time a subscriber copies over data from the origin, it sees all tables in a state somewhere between two SYNC events. Therefore this list must contains all XIDs that are visible at that time, whose operations have therefore already been included in the data copied at the time the initial data copy is done.  Those actions may therefore be filtered out of the first SYNC done after subscribing.';
+comment on column @NAMESPACE@.sl_setsync.ssy_snapshot is 'TXID in provider system seen by the event';
+comment on column @NAMESPACE@.sl_setsync.ssy_action_list is 'action list used during the subscription process. At the time a subscriber copies over data from the origin, it sees all tables in a state somewhere between two SYNC events. Therefore this list must contains all log_actionseqs that are visible at that time, whose operations have therefore already been included in the data copied at the time the initial data copy is done.  Those actions may therefore be filtered out of the first SYNC done after subscribing.';
 
 
 -- ----------------------------------------------------------------------
@@ -135,25 +128,6 @@ comment on column @NAMESPACE@.sl_table.tab_altered is 'Has the table been modifi
 comment on column @NAMESPACE@.sl_table.tab_comment is 'Human-oriented description of the table';
 
 
--- ----------------------------------------------------------------------
--- TABLE sl_trigger
--- ----------------------------------------------------------------------
-create table @NAMESPACE@.sl_trigger (
-	trig_tabid			int4,
-	trig_tgname			name,
-
-	CONSTRAINT "sl_trigger-pkey"
-		PRIMARY KEY (trig_tabid, trig_tgname),
-	CONSTRAINT "trig_tabid-tab_id-ref"
-		FOREIGN KEY (trig_tabid)
-		REFERENCES @NAMESPACE@.sl_table (tab_id)
-		ON DELETE CASCADE
-) WITHOUT OIDS;
-comment on table @NAMESPACE@.sl_trigger is 'Holds information about triggers on tables managed using Slony-I';
-comment on column @NAMESPACE@.sl_trigger.trig_tabid is 'Slony-I ID number of table the trigger is on';
-comment on column @NAMESPACE@.sl_trigger.trig_tgname is 'Indicates the name of a trigger';
-
-
 -- ----------------------------------------------------------------------
 -- TABLE sl_sequence
 -- ----------------------------------------------------------------------
@@ -174,7 +148,7 @@ create table @NAMESPACE@.sl_sequence (
 comment on table @NAMESPACE@.sl_sequence is 'Similar to sl_table, each entry identifies a sequence being replicated.';
 comment on column @NAMESPACE@.sl_sequence.seq_id is 'An internally-used ID for Slony-I to use in its sequencing of updates';
 comment on column @NAMESPACE@.sl_sequence.seq_reloid is 'The OID of the sequence object';
-comment on column @NAMESPACE@.sl_sequence.seq_relname is 'The name of the sdequence in pg_catalog.pg_class.relname used to recover from a dump/restore cycle'; 
+comment on column @NAMESPACE@.sl_sequence.seq_relname is 'The name of the sequence in pg_catalog.pg_class.relname used to recover from a dump/restore cycle'; 
 comment on column @NAMESPACE@.sl_sequence.seq_nspname is 'The name of the schema in pg_catalog.pg_namespace.nspname used to recover from a dump/restore cycle'; 
 comment on column @NAMESPACE@.sl_sequence.seq_set is 'Indicates which replication set the object is in';
 comment on column @NAMESPACE@.sl_sequence.seq_comment is 'A human-oriented comment';
@@ -262,9 +236,7 @@ create table @NAMESPACE@.sl_event (
 	ev_origin			int4,
 	ev_seqno			int8,
 	ev_timestamp		timestamp,
-	ev_minxid			@NAMESPACE@.xxid,
-	ev_maxxid			@NAMESPACE@.xxid,
-	ev_xip				text,
+	ev_snapshot			"pg_catalog".txid_snapshot,
 	ev_type				text,
 	ev_data1			text,
 	ev_data2			text,
@@ -282,10 +254,8 @@ comment on table @NAMESPACE@.sl_event is 'Holds information about replication ev
 comment on column @NAMESPACE@.sl_event.ev_origin is 'The ID # (from sl_node.no_id) of the source node for this event';
 comment on column @NAMESPACE@.sl_event.ev_seqno is 'The ID # for the event';
 comment on column @NAMESPACE@.sl_event.ev_timestamp is 'When this event record was created';
-comment on column @NAMESPACE@.sl_event.ev_minxid is 'Earliest XID on provider node for this event';
-comment on column @NAMESPACE@.sl_event.ev_maxxid is 'Latest XID on provider node for this event';
+comment on column @NAMESPACE@.sl_event.ev_snapshot is 'TXID snapshot on provider node for this event';
 comment on column @NAMESPACE@.sl_event.ev_seqno is 'The ID # for the event';
-comment on column @NAMESPACE@.sl_event.ev_xip is 'List of XIDs, in order, that are part of this event';
 comment on column @NAMESPACE@.sl_event.ev_type is 'The type of event this record is for.  
 				SYNC				= Synchronise
 				STORE_NODE			=
@@ -397,22 +367,22 @@ last value from the requested sequence.';
 -- ----------------------------------------------------------------------
 create table @NAMESPACE@.sl_log_1 (
 	log_origin			int4,
-	log_xid				@NAMESPACE@.xxid,
+	log_txid			bigint,
 	log_tableid			int4,
 	log_actionseq		int8,
 	log_cmdtype			char,
 	log_cmddata			text
 ) WITHOUT OIDS;
 create index sl_log_1_idx1 on @NAMESPACE@.sl_log_1
-	(log_origin, log_xid @NAMESPACE@.xxid_ops, log_actionseq);
+	(log_origin, log_txid, log_actionseq);
 
 -- Add in an additional index as sometimes log_origin isn't a useful discriminant
 -- create index sl_log_1_idx2 on @NAMESPACE@.sl_log_1
---	(log_xid @NAMESPACE@.xxid_ops);
+--	(log_txid);
 
 comment on table @NAMESPACE@.sl_log_1 is 'Stores each change to be propagated to subscriber nodes';
 comment on column @NAMESPACE@.sl_log_1.log_origin is 'Origin node from which the change came';
-comment on column @NAMESPACE@.sl_log_1.log_xid is 'Transaction ID on the origin node';
+comment on column @NAMESPACE@.sl_log_1.log_txid is 'Transaction ID on the origin node';
 comment on column @NAMESPACE@.sl_log_1.log_tableid is 'The table ID (from sl_table.tab_id) that this log entry is to affect';
 comment on column @NAMESPACE@.sl_log_1.log_cmdtype is 'Replication action to take. U = Update, I = Insert, D = DELETE';
 comment on column @NAMESPACE@.sl_log_1.log_cmddata is 'The data needed to perform the log action';
@@ -422,7 +392,7 @@ comment on column @NAMESPACE@.sl_log_1.log_cmddata is 'The data needed to perfor
 -- ----------------------------------------------------------------------
 create table @NAMESPACE@.sl_log_2 (
 	log_origin			int4,
-	log_xid				@NAMESPACE@.xxid,
+	log_txid			bigint,
 	log_tableid			int4,
 	log_actionseq		int8,
 	log_cmdtype			char,
@@ -430,16 +400,16 @@ create table @NAMESPACE@.sl_log_2 (
 ) WITHOUT OIDS;
 comment on table @NAMESPACE@.sl_log_2 is 'Stores each change to be propagated to subscriber nodes';
 comment on column @NAMESPACE@.sl_log_2.log_origin is 'Origin node from which the change came';
-comment on column @NAMESPACE@.sl_log_2.log_xid is 'Transaction ID on the origin node';
+comment on column @NAMESPACE@.sl_log_2.log_txid is 'Transaction ID on the origin node';
 comment on column @NAMESPACE@.sl_log_2.log_tableid is 'The table ID (from sl_table.tab_id) that this log entry is to affect';
 comment on column @NAMESPACE@.sl_log_2.log_cmdtype is 'Replication action to take. U = Update, I = Insert, D = DELETE';
 comment on column @NAMESPACE@.sl_log_2.log_cmddata is 'The data needed to perform the log action';
 create index sl_log_2_idx1 on @NAMESPACE@.sl_log_2
-	(log_origin, log_xid @NAMESPACE@.xxid_ops, log_actionseq);
+	(log_origin, log_txid, log_actionseq);
 
 -- Add in an additional index as sometimes log_origin isn't a useful discriminant
 -- create index sl_log_2_idx2 on @NAMESPACE@.sl_log_2
--- 	(log_xid @NAMESPACE@.xxid_ops);
+-- 	(log_txid);
 
 
 -- ----------------------------------------------------------------------
@@ -499,6 +469,7 @@ comment on sequence @NAMESPACE@.sl_local_node_id is 'The local node ID is initia
 -- ----------------------------------------------------------------------
 create sequence @NAMESPACE@.sl_event_seq;
 comment on sequence @NAMESPACE@.sl_event_seq is 'The sequence for numbering events originating from this node.';
+select setval('@NAMESPACE@.sl_event_seq', 5000000000);
 
 -- ----------------------------------------------------------------------
 -- SEQUENCE sl_action_seq
@@ -512,17 +483,6 @@ comment on sequence @NAMESPACE@.sl_action_seq is 'The sequence to number stateme
 
 
 
--- ----------------------------------------------------------------------
--- SEQUENCE sl_rowid_seq
---
---	Application tables that do not have a natural primary key must
---	be modified and an int8 column added that serves as a rowid for us.
---	The values are assigned with a default from this sequence.
--- ----------------------------------------------------------------------
-create sequence @NAMESPACE@.sl_rowid_seq;
-grant select, update on @NAMESPACE@.sl_rowid_seq to public;
-comment on sequence @NAMESPACE@.sl_rowid_seq is 'Application tables that do not have a natural primary key must be modified and an int8 column added that serves as a rowid for us.  The values are assigned with a default from this sequence.';
-
 
 -- ----------------------------------------------------------------------
 -- SEQUENCE sl_log_status
